@@ -5,6 +5,7 @@ package testdata
 import (
 	"log"
 	"net/http"
+	"os"
 	"time"
 )
 
@@ -21,4 +22,7 @@ func Mnd() {
 	if res.StatusCode != 200 { // want "Magic number: 200, in <condition> detected"
 		log.Println("Something went wrong")
 	}
+
+	_ = os.Mkdir("my/dir", 0777)
+	_ = os.Mkdir("my/dir", 0775) // want "Magic number: 0775, in <argument> detected"
 }
